import 'dart:convert';

import 'package:flutter/material.dart';
import 'dart:async';

import 'package:flutter_facebook_login_web/flutter_facebook_login_web.dart';
import 'package:http/http.dart' as http;

//import 'package:flutter_facebook_login/flutter_facebook_login.dart';

void main() {
  runApp(MyApp());
}

class MyApp extends StatefulWidget {
  @override
  _MyAppState createState() => _MyAppState();
}

class _MyAppState extends State<MyApp> {
  String _message = '';
  bool _isLogged = false;
  String _username = '';
  String _profileUrl = '';
  String _email = '';

  static final facebookSignIn = FacebookLoginWeb();

  bool _status;

  @override
  initState() {
    super.initState();
    facebookSignIn.isLoggedIn.then((status) => _showStatus(status));
  }

  Future<Null> _login() async {
    final FacebookLoginResult result = await facebookSignIn.logIn(['email']);

    switch (result.status) {
      case FacebookLoginStatus.loggedIn:
        final FacebookAccessToken accessToken = result.accessToken;
        _showMessage('''
         Logged in!
         
         Token: ${accessToken.token}
         User id: ${accessToken.userId}
         ''');

        var status = await facebookSignIn.isLoggedIn;
        _showStatus(status);

        var response = await http.get(
            'https://graph.facebook.com/${accessToken.userId}?fields=name,birthday,email,picture.width(720).height(720)&access_token=${accessToken.token}');
        var data = jsonDecode(response.body);

        setState(() {
          _username = data['name'];
          _profileUrl = data['picture']['data']['url'];
          _email = data['email'];
        });

//        facebookSignIn.testApi();
        _isLogged = true;
        break;
      case FacebookLoginStatus.cancelledByUser:
        _showMessage('Login cancelled by the user.');
        break;
      case FacebookLoginStatus.error:
        _showMessage('Something went wrong with the login process.\n'
            'Here\'s the error Facebook gave us: ${result.errorMessage}');
        break;
    }
  }

  Future<Null> _logOut() async {
    await facebookSignIn.logOut();
    _isLogged = false;
    _showStatus(false);
    _showMessage('Logged out.');
  }

  void _showMessage(String message) {
    setState(() {
      _message = message;
    });
  }

  void _showStatus(bool status) {
    setState(() {
      _status = status;
    });
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      home: Scaffold(
        appBar: AppBar(
          title: const Text('Facebook Login Web'),
        ),
        body: Center(
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              Text('facebookSignIn.isLoggedIn = $_status'),
              Text(_message),
              (_isLogged == true)
                  ? Image.network(_profileUrl, height: 140, width: 140)
                  : Container(),
              (_isLogged == true) ? Text('Logged as $_username') : Container(),
              _isLogged == false
                  ? RaisedButton(
                      color: Colors.indigo[900],
                      onPressed: _login,
                      child: Text("Login with Facebook",
                          style: TextStyle(
                              color: Colors.white,
                              fontWeight: FontWeight.bold)),
                    )
                  : RaisedButton(
                      color: Colors.indigo[900],
                      onPressed: _logOut,
                      child: Text("Logout",
                          style: TextStyle(
                              color: Colors.white,
                              fontWeight: FontWeight.bold)),
                    ),
            ],
          ),
        ),
      ),
    );
  }
}
